@@ -724,6 +724,7 @@ impl<W: Write + Seek> ZipDirectoryWriter<W> {
         // Set file permissions: 644 (rw-r--r--) for regular files, 755 (rwxr-xr-x) for executables
         let permissions = if executable_bit { 0o755 } else { 0o644 };
         let options = zip::write::SimpleFileOptions::default()
+            .system(zip::System::Unix)
             .unix_permissions(permissions)
             .compression_method(self.compression);
         self.writer.start_file(path, options)?;
@@ -736,6 +737,7 @@ impl<W: Write + Seek> DirectoryWriter for ZipDirectoryWriter<W> {
         trace!("Adding {}", path);
         // Set appropriate permissions for metadata files (644 = rw-r--r--)
         let options = zip::write::SimpleFileOptions::default()
+            .system(zip::System::Unix)
             .unix_permissions(0o644)
             .compression_method(self.compression);
         self.writer.start_file(path, options)?;
@@ -772,7 +774,9 @@ impl<W: Write + Seek> DirectoryWriter for ZipDirectoryWriter<W> {
 
     fn write_directory(&mut self, directory: &str) -> Result<(), Error> {
         trace!("Adding directory {}", directory);
-        let options = zip::write::SimpleFileOptions::default().compression_method(self.compression);
+        let options = zip::write::SimpleFileOptions::default()
+            .compression_method(self.compression)
+            .system(zip::System::Unix);
         Ok(self.writer.add_directory(directory, options)?)
     }
 
