@@ -3,8 +3,9 @@ pub use download::LocalWheel;
 pub use error::Error;
 pub use index::{BuiltWheelIndex, RegistryWheelIndex};
 pub use metadata::{
-    ArchiveMetadata, BuildRequires, ExtraBuildRequires, FlatRequiresDist, LoweredRequirement,
-    LoweringError, Metadata, MetadataError, RequiresDist, SourcedDependencyGroups,
+    ArchiveMetadata, BuildRequires, FlatRequiresDist, LoweredExtraBuildDependencies,
+    LoweredRequirement, LoweringError, Metadata, MetadataError, RequiresDist,
+    SourcedDependencyGroups,
 };
 pub use reporter::Reporter;
 pub use source::prune;
