@@ -1,10 +1,10 @@
 use uv_static::EnvVars;
 
-use crate::common::{TestContext, uv_snapshot};
+use uv_test::uv_snapshot;
 
 #[test]
 fn help() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     // The `uv help` command should show the long help message
     uv_snapshot!(context.filters(), context.help(), @r#"
@@ -86,7 +86,7 @@ fn help() {
 
 #[test]
 fn help_flag() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.command().arg("--help"), @r#"
     success: true
@@ -165,7 +165,7 @@ fn help_flag() {
 
 #[test]
 fn help_short_flag() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.command().arg("-h"), @r#"
     success: true
@@ -244,7 +244,7 @@ fn help_short_flag() {
 
 #[test]
 fn help_subcommand() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().arg("python"), @r#"
     success: true
@@ -458,7 +458,7 @@ fn help_subcommand() {
 
 #[test]
 fn help_subsubcommand() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().env_remove(EnvVars::UV_PYTHON_INSTALL_DIR).arg("python").arg("install"), @r#"
     success: true
@@ -742,7 +742,7 @@ fn help_subsubcommand() {
 
 #[test]
 fn help_flag_subcommand() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.command().arg("python").arg("--help"), @r#"
     success: true
@@ -807,7 +807,7 @@ fn help_flag_subcommand() {
 
 #[test]
 fn help_flag_subsubcommand() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.command().arg("python").arg("install").arg("--help"), @r#"
     success: true
@@ -888,7 +888,7 @@ fn help_flag_subsubcommand() {
 
 #[test]
 fn help_unknown_subcommand() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().arg("foobar"), @"
     success: false
@@ -951,7 +951,7 @@ fn help_unknown_subcommand() {
 
 #[test]
 fn help_unknown_subsubcommand() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().arg("python").arg("foobar"), @"
     success: false
@@ -973,7 +973,7 @@ fn help_unknown_subsubcommand() {
 
 #[test]
 fn help_with_global_option() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().arg("--no-cache"), @r#"
     success: true
@@ -1054,7 +1054,7 @@ fn help_with_global_option() {
 
 #[test]
 fn help_with_help() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().arg("--help"), @"
     success: true
@@ -1073,7 +1073,7 @@ fn help_with_help() {
 
 #[test]
 fn help_with_version() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     uv_snapshot!(context.filters(), context.help().arg("--version"), @"
     success: false
@@ -1093,7 +1093,7 @@ fn help_with_version() {
 
 #[test]
 fn help_with_no_pager() {
-    let context = TestContext::new_with_versions(&[]);
+    let context = uv_test::test_context_with_versions!(&[]);
 
     // We can't really test whether the --no-pager option works with a snapshot test.
     // It's still nice to have a test for the option to confirm the option exists.
